@@ -8,8 +8,19 @@ export class LabTestPanelExporter extends DefaultDataExporter {
           model: this.models.LabTestType,
           as: 'labTestTypes',
           attributes: ['id'],
+          through: {
+            attributes: ['order'],
+          },
         },
       ],
+      order: [
+        [
+          'labTestTypes',
+          this.models.LabTestPanelLabTestTypes,
+          'order',
+          'ASC',
+        ],
+      ],
     });
 
     return labTestPanels.map(({ dataValues: { labTestTypes, ...rest } }) => ({
