@@ -1,4 +1,4 @@
-import { fake } from '@tamanu/shared/test-helpers';
+import { fake } from '@tamanu/fake-data/fake';
 import { ENCOUNTER_TYPES } from '@tamanu/constants';
 
 import { chance } from '../chance';
